@@ -1,7 +1,6 @@
 package Pcore::Core::Log::Pipe::xmpp;    ## no critic qw[NamingConventions::Capitalization]
 
 use Pcore -class;
-use Pcore::Handle;
 
 extends qw[Pcore::Core::Log::Pipe];
 
@@ -20,7 +19,7 @@ sub _build_id ($self) {
 }
 
 sub _build_h ($self) {
-    return Pcore::Handle->new( $self->uri );
+    return P->handle( $self->uri );
 }
 
 sub sendlog ( $self, $header, $data, $tag ) {
