@@ -1,15 +1,13 @@
-package Pcore::Handle::xmpp;
+package Pcore::Handle::xmpp;    ## no critic qw[NamingConventions::Capitalization]
 
 use Pcore -class;
 use Net::XMPP;
 use Mozilla::CA;
 
-with qw[Pcore::Core::H::Role::Wrapper];
+with qw[Pcore::Handle::Wrapper];
 
-has addr => ( is => 'ro', isa => Str, required => 1 );    # file://<path>, memory:// and temp:// schemes allowed, memory:// and temp:// not shared between processes
-
-sub h_connect ($self) {
-    my $uri = P->uri( $self->addr );
+sub _connect ($self) {
+    my $uri = $self->uri;
 
     my $h = Net::XMPP::Client->new;
 
@@ -34,13 +32,13 @@ sub h_connect ($self) {
         resource => $resource,
     );
 
-    die 'XMPP authentication error' unless $auth_res[0] eq 'ok';
+    die 'XMPP authentication error' if !@auth_res || $auth_res[0] ne 'ok';
 
     return $h;
 }
 
-sub h_disconnect ($self) {
-    $self->h->Disconnect if ${^GLOBAL_PHASE} ne 'DESTRUCT';
+sub _disconnect ($self) {
+    $self->h->Disconnect;
 
     return;
 }
@@ -58,7 +56,9 @@ sub sendmsg ( $self, $to, $msg ) {
 ## +------+----------------------+----------------------------------------------------------------------------------------------------------------+
 ## | Sev. | Lines                | Policy                                                                                                         |
 ## |======+======================+================================================================================================================|
-## |    1 | 1                    | NamingConventions::Capitalization - Package "Pcore::Handle::xmpp" does not start with a upper case letter      |
+## |    3 |                      | Subroutines::ProhibitUnusedPrivateSubroutines                                                                  |
+## |      | 9                    | * Private subroutine/method '_connect' declared but not used                                                   |
+## |      | 40                   | * Private subroutine/method '_disconnect' declared but not used                                                |
 ## +------+----------------------+----------------------------------------------------------------------------------------------------------------+
 ##
 ## -----SOURCE FILTER LOG END-----
