@@ -1,4 +1,4 @@
-package Pcore::XMPP v0.7.0;
+package Pcore::XMPP v0.7.1;
 
 use Pcore -dist;
 
@@ -15,7 +15,7 @@ Pcore::XMPP
 =head1 SYNOPSIS
 
     # create handle
-    my $xmpp = Pcore::Handle->new('xmpp://username:password@gmail.com?gtalk');
+    my $xmpp = P->handle('xmpp://username:password@gmail.com?gtalk');
 
     # send message
     $xmpp->sendmsg( 'to_user@gmail.com', 'message' );
